@@ -2,8 +2,8 @@
 average-minimum-distance: isometrically invariant crystal fingerprints
 ======================================================================
 
-Documentation is available in the docstrings and
-online at https://average-minimum-distance.readthedocs.io.
+Documentation is available in the docstrings and online at
+https://average-minimum-distance.readthedocs.io.
 
 List of modules
 ***************
@@ -12,14 +12,14 @@ List of modules
 Module                 Description
 ===================    ==============================================================
 :mod:`.calculate`      Calculate invariants (descriptors) of periodic sets (crystals)
-:mod:`.compare`        Compare fingerprints of crystals
+:mod:`.compare`        Compare invariants of crystals
 :mod:`.io`             Read periodic sets from a file or the CSD
 :mod:`.periodicset`    Implements the PeriodicSet object
-:mod:`.utils`          General utility functions
+:mod:`.utils`          Utility functions
 ===================    ==============================================================
 """
 
-__version__ = '1.3.3'
+__version__ = '1.3.4'
 __author__ = 'Daniel Widdowson'
 __maintainer__ = 'Daniel Widdowson'
 __email__ = 'D.E.Widdowson@liverpool.ac.uk'
@@ -30,6 +30,5 @@ __copyright__ = "Copyright 2022, Daniel Widdowson"
 from .calculate import *
 from .compare import *
 from .io import *
-from .periodicset import PeriodicSet
-from .reconstruct import reconstruct
+from .periodicset import *
 from .utils import *
