@@ -1,13 +1,14 @@
 """General utility functions."""
 
 from typing import Tuple
+import sys
+import time
+import datetime
 
 import numpy as np
 import numba
 from scipy.spatial.distance import squareform
 
-from .periodicset import PeriodicSet
-
 
 def diameter(cell):
     """Diameter of a unit cell (as a square matrix in Cartesian/Orthogonal form)
@@ -23,11 +24,12 @@ def diameter(cell):
             cell[0] + cell[1] + cell[2],
             cell[0] + cell[1] - cell[2],
             cell[0] - cell[1] + cell[2],
-            -cell[0] + cell[1] + cell[2]
+            - cell[0] + cell[1] + cell[2]
         ])
-        d =  np.amax(np.linalg.norm(diams, axis=-1))
+        d = np.amax(np.linalg.norm(diams, axis=-1))
     else:
-        raise ValueError(f'diameter only implimented for dimensions <= 3.')
+        msg = f'diameter() not implemented for dims > 3 (passed cell shape {cell.shape}).'
+        raise NotImplementedError(msg)
     return d
 
 
@@ -37,7 +39,7 @@ def cellpar_to_cell(a, b, c, alpha, beta, gamma):
     3D unit cell parameters a,b,c,α,β,γ --> cell as 3x3 NumPy array.
     """
 
-    eps = 2 * np.spacing(90.0)
+    eps = 2 * np.spacing(90.0)  # ~1.4e-14
 
     cos_alpha = 0. if abs(abs(alpha) - 90.) < eps else np.cos(alpha * np.pi / 180.)
     cos_beta = 0. if abs(abs(beta) - 90.) < eps else np.cos(beta * np.pi / 180.)
@@ -78,6 +80,27 @@ def cellpar_to_cell_2D(a, b, alpha):
     return cell
 
 
+def cell_to_cellpar(cell):
+    """Unit cell as a 3x3 NumPy array -> list of 6 lengths + angles."""
+    lengths = np.linalg.norm(cell, axis=-1)
+    angles = []
+    for i, j in [(1, 2), (0, 2), (0, 1)]:
+        ang_rad = np.arccos(np.dot(cell[i], cell[j]) / (lengths[i] * lengths[j]))
+        angles.append(np.rad2deg(ang_rad))
+    return np.concatenate((lengths, np.array(angles)))
+
+
+def cell_to_cellpar_2D(cell):
+    """Unit cell as a 2x2 NumPy array -> list of 2 lengths and an angle."""
+    cellpar = np.zeros((3, ))
+    lengths = np.linalg.norm(cell, axis=-1)
+    ang_rad = np.arccos(np.dot(cell[0], cell[1]) / (lengths[0] * lengths[1]))
+    cellpar[0] = lengths[0]
+    cellpar[1] = lengths[1]
+    cellpar[2] = np.rad2deg(ang_rad)
+    return cellpar
+
+
 def neighbours_from_distance_matrix(
         n: int,
         dm: np.ndarray
@@ -88,15 +111,15 @@ def neighbours_from_distance_matrix(
     ----------
     n : int
         Number of nearest neighbours to find for each item.
-    dm : numpy.ndarray
+    dm : :class:`numpy.ndarray`
         2D distance matrix or 1D condensed distance matrix.
 
     Returns
     -------
-    nn_dm, inds : Tuple[numpy.ndarray, numpy.ndarray] 
-        ``nn_dm[i][j]`` is the distance from item ``i`` to its ``j+1`` st
-        nearest neighbour, and ``inds[i][j]`` is the index of this neighbour 
-        (``j+1`` since index 0 is the first nearest neighbour).
+    (nn_dm, inds) : Tuple[:class:`numpy.ndarray`, :class:`numpy.ndarray`]
+        ``nn_dm[i][j]`` is the distance from item :math:`i` to its :math:`j+1` st
+        nearest neighbour, and ``inds[i][j]`` is the index of this neighbour
+        (:math:`j+1` since index 0 is the first nearest neighbour).
     """
 
     inds = None
@@ -128,32 +151,17 @@ def neighbours_from_distance_matrix(
     return nn_dm, inds
 
 
-def lattice_cubic(scale=1, dims=3):
-    """Return a pair ``(motif, cell)`` representing a hexagonal lattice, passable to
-    ``amd.AMD()`` or ``amd.PDD()``. """
-
-    return PeriodicSet(np.zeros((1, dims)), np.identity(dims) * scale)
-
-
-def lattice_hexagonal(scale=1):
-    """Dimension 3 only. Return a pair ``(motif, cell)`` representing a cubic lattice, 
-    passable to ``amd.AMD()`` or ``amd.PDD()``."""
-
-    return PeriodicSet(np.zeros((1, 3)), cellpar_to_cell(scale, scale, scale, 90, 90, 120))
-
-
 def random_cell(length_bounds=(1, 2), angle_bounds=(60, 120), dims=3):
-    """Dimensions 2 and 3 only. Random unit cell with uniformally chosen length and 
+    """Dimensions 2 and 3 only. Random unit cell with uniformally chosen length and
     angle parameters between bounds."""
 
+    ll, lu = length_bounds
+    al, au = angle_bounds
+
     if dims == 3:
         while True:
-            lengths = [np.random.uniform(low=length_bounds[0],
-                                         high=length_bounds[1])
-                       for _ in range(dims)]
-            angles = [np.random.uniform(low=angle_bounds[0],
-                                        high=length_bounds[1])
-                      for _ in range(dims)]
+            lengths = [np.random.uniform(low=ll, high=lu) for _ in range(dims)]
+            angles = [np.random.uniform(low=al, high=au) for _ in range(dims)]
 
             try:
                 cell = cellpar_to_cell(*lengths, *angles)
@@ -162,14 +170,65 @@ def random_cell(length_bounds=(1, 2), angle_bounds=(60, 120), dims=3):
                 continue
 
     elif dims == 2:
-        lengths = [np.random.uniform(low=length_bounds[0],
-                                     high=length_bounds[1])
-                       for _ in range(dims)]
-        alpha = np.random.uniform(low=angle_bounds[0],
-                                  high=length_bounds[1])
+        lengths = [np.random.uniform(low=ll, high=lu) for _ in range(dims)]
+        alpha = np.random.uniform(low=al, high=au)
         cell = cellpar_to_cell_2D(*lengths, alpha)
 
     else:
         raise ValueError(f'random_cell only implimented for dimensions 2 and 3 (passed {dims})')
 
     return cell
+
+
+class _ETA:
+    """Pass the number to items to process, then call .update() on every loop.
+    """
+
+    # epochtime_{n+1} = factor * epochtime + (1-factor) * epochtime_{n}
+    _moving_av_factor = 0.3
+
+    def __init__(self, to_do, update_rate=1000):
+        self.to_do = to_do
+        self.update_rate = update_rate
+        self.counter = 0
+        self.this_epoch = 0
+        self.start_time = time.perf_counter()
+        self.time_per_epoch = None
+        self.done = False
+        self.tic = self.start_time
+
+    def update(self):
+        """Call on each loop."""
+
+        self.counter += 1
+
+        if self.counter >= self.to_do:
+            if not self.done:
+                self.finish()
+            return
+
+        elif not self.counter % self.update_rate:
+            self.end_epoch()
+
+    def finish(self):
+        """Called when done."""
+        total = time.perf_counter() - self.start_time
+        self.done = True
+        msg = f'Time ({self.counter} items): {round(total, 2)}s, ' \
+              f'{round(self.to_do/total, 2)} items/s\r\n'
+        sys.stdout.write(msg)
+
+    def end_epoch(self):
+        """Called at the end of every epoch, printing the ETA to stdout."""
+        toc = time.perf_counter()
+        epoch_time = toc - self.tic
+        if self.time_per_epoch is None:
+            self.time_per_epoch = epoch_time
+        else:
+            self.time_per_epoch = _ETA._moving_av_factor * epoch_time + \
+                                  (1 - _ETA._moving_av_factor) * self.time_per_epoch
+        percent = round(100 * self.counter / self.to_do, 2)
+        remaining = int(((self.to_do - self.counter) / self.update_rate) * self.time_per_epoch)
+        eta = str(datetime.timedelta(seconds=remaining))
+        self.tic = time.perf_counter()
+        sys.stdout.write(f'{percent}%, ETA {eta}' + ' ' * 20 + '\r')
